.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    lun 10 nov 2008 12:32:25 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

=============
 User manual
=============

.. toctree::
   :maxdepth: 4

   userinterface
   printouts
   appendixes

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
